package com.winhc.business.widget;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.support.annotation.NonNull;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.view.WindowManager;

import com.chad.library.adapter.base.BaseQuickAdapter;
import com.chad.library.adapter.base.BaseViewHolder;
import com.winhc.business.R;
import com.winhc.business.builder.BaseDialog;
import com.winhc.business.utils.NoDoubleClickUtils;
import com.winhc.business.widget.bean.RightOperateBean;
import com.winhc.widget.util.ScreenUtil;

import java.util.ArrayList;

/**
 * 右上角操作弹框
 * create by toby
 * on 2021/4/7.
 */
public class RightOperateDialog extends BaseDialog {

    RecyclerView base_recycler_view;

    private BaseQuickAdapter<RightOperateBean, BaseViewHolder> adapter;
    private ArrayList<RightOperateBean> rightOperateBeans;
    private OnDialogItemClickListener clickListener;

    public RightOperateDialog(Context context, ArrayList<RightOperateBean> rightOperateBeans, OnDialogItemClickListener clickListener) {
        super(context);
        this.rightOperateBeans = rightOperateBeans;
        this.clickListener = clickListener;
    }

    @Override
    public View getView(Context context) {
        View view_pop = LayoutInflater.from(context).inflate(R.layout.pop_right_operate_dialog_layout, null);
        base_recycler_view = view_pop.findViewById(R.id.base_recycler_view);
        initRecycler();
        return view_pop;
    }

    @Override
    protected int getWindowAnimations() {
        return R.style.PopAnimation_Down_Up;
    }

    @Override
    protected void setWindow() {
        //设置弹出位置
        Window dialogWindow = mDialog.getWindow();
        if (null != dialogWindow) {
            dialogWindow.setDimAmount(0);//设置昏暗度为0
            dialogWindow.setGravity(Gravity.TOP | Gravity.RIGHT);
            WindowManager.LayoutParams lp = dialogWindow.getAttributes();
            lp.width = ScreenUtil.dip2px(135);
            lp.height = ViewGroup.LayoutParams.WRAP_CONTENT;
            lp.x = ScreenUtil.dip2px(10);
            //设置出现的高度，距离顶部
            lp.y = ScreenUtil.dip2px(40);
            dialogWindow.setAttributes(lp);
            dialogWindow.setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
        }
    }

    private void initRecycler() {
        base_recycler_view.setLayoutManager(new LinearLayoutManager(mContext));
        LineDecoration decoration = new LineDecoration(
                Color.parseColor("#242424"), ScreenUtil.dip2px(1), 0, 0);
        decoration.setDrawLastItem(false);
        base_recycler_view.addItemDecoration(decoration);
        adapter = new BaseQuickAdapter<RightOperateBean, BaseViewHolder>(R.layout.item_dialog_right_operate, rightOperateBeans) {
            @Override
            protected void convert(@NonNull BaseViewHolder baseViewHolder, RightOperateBean data) {
                if (data != null) {
                    baseViewHolder.setImageResource(R.id.imageView, data.getResId())
                            .setText(R.id.operateName, data.getOperateName());
                }
            }
        };
        base_recycler_view.setAdapter(adapter);
        adapter.setOnItemClickListener(new BaseQuickAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(BaseQuickAdapter baseQuickAdapter, View view, int position) {
                if (position > -1) {
                    if (!NoDoubleClickUtils.isDoubleClick()) {
                        if (null != clickListener)
                            clickListener.onDialogItemClick(adapter.getItem(position).getCode());
                        cancel();
                    }
                }
            }
        });
    }

    public interface OnDialogItemClickListener {
        void onDialogItemClick(int code);
    }
}
